pub struct BrickBeam<T: PulseTransmitter = DefaultPulseTransmitter> { /* private fields */ }Expand description
The primary API for creating various remote controllers for LEGO IR transmission.
This struct abstracts the details of the underlying PulseTransmitter.
On Linux, with the default Cargo feature cir, it uses cir crate that uses the Linux kernel’s LIRC (rc-core) drivers for IR transmitter.
on other platforms, it uses an emulator that is intended only for quick and easy compilation, not for production use.
Once initialized, you can create remote controllers that wrap the underlying LEGO® IR transmission protocols.
Specifically, BrickBeam provides methods to obtain a remote controller
- for the Single Output protocol via create_speed_remote_controller(),
- for the Combo PWM protocol via create_combo_speed_remote_controller(),
- for the Combo Direct protocol via create_direct_remote_controller(),
- and for the Extended protocol via create_extended_remote_controller().
Examples
use brickbeam::{BrickBeam, Channel, Output, SingleOutputCommand, Result};
fn main() -> Result<()> {
let brick_beam = BrickBeam::new("/dev/lirc0")?;
let mut motor = brick_beam.create_speed_remote_controller(Channel::One, Output::RED)?;
motor.send(SingleOutputCommand::PWM(5))?;
Ok(())
}Implementations
Sourceimpl BrickBeam<DefaultPulseTransmitter>
impl BrickBeam<DefaultPulseTransmitter>
Sourcepub fn new(tx_device_path: impl AsRef<Path>) -> Result<Self>
pub fn new(tx_device_path: impl AsRef<Path>) -> Result<Self>
Creates a new BrickBeam instance using the Linux Kernel’s LIRC (rc-core) IR transmitter.
This function initializes a BrickBeam instance by setting up the Linux-specific IR transmitter.
Arguments
tx_device_path- A path reference to the kernel transmission device, such as /dev/lirc0.
Returns
Result<Self>- A result containing the newBrickBeaminstance or an error.
Sourceimpl<T: PulseTransmitter> BrickBeam<T>
impl<T: PulseTransmitter> BrickBeam<T>
Sourcepub fn create_speed_remote_controller(
&self,
channel: Channel,
output: Output,
) -> Result<SpeedRemoteController<'_, T>>
pub fn create_speed_remote_controller( &self, channel: Channel, output: Output, ) -> Result<SpeedRemoteController<'_, T>>
Creates a Speed Remote Controller using the Single Output protocol.
Arguments
channel- The channel (1 to 4) to be used for the controller.output- The output (Red, Blue) to be used for the controller.
Returns
Result<SpeedRemoteController<T>>- A result containing the newSpeedRemoteControllerinstance or an error.
Sourcepub fn create_combo_speed_remote_controller(
&self,
channel: Channel,
) -> Result<ComboSpeedRemoteController<'_, T>>
pub fn create_combo_speed_remote_controller( &self, channel: Channel, ) -> Result<ComboSpeedRemoteController<'_, T>>
Sourcepub fn create_direct_remote_controller(
&self,
channel: Channel,
) -> Result<DirectRemoteController<'_, T>>
pub fn create_direct_remote_controller( &self, channel: Channel, ) -> Result<DirectRemoteController<'_, T>>
Sourcepub fn create_extended_remote_controller(
&self,
channel: Channel,
) -> Result<ExtendedRemoteController<'_, T>>
pub fn create_extended_remote_controller( &self, channel: Channel, ) -> Result<ExtendedRemoteController<'_, T>>